function ContainerLoader(JSONContainerLoader, ContainerDecoratorProvider, ZHPromise, ScreenService) {

	var concreteContainerLoader = JSONContainerLoader;
	var containerDecoratorProvider = ContainerDecoratorProvider;

	this.setConcreteContainerLoader = function(concreteLoader) {
		if (concreteLoader && Util.isFunction(concreteLoader.loadContainer)) {
			concreteContainerLoader = concreteLoader;
		} else {
			throw ScreenService.i18n("Invalid parameters or your class doesn't have a loadContainer method.");
		}
	};

	this.setContainerDecoratorProvider = function(decoratorProvider) {
		if(decoratorProvider && Util.isFunction(decoratorProvider.provide)) {
			containerDecoratorProvider = decoratorProvider;
		} else {
			throw ScreenService.i18n("Invalid parameters or your class doesn't have a provide method.");
		}
	};

	this.loadContainer = function(name) {
		if (concreteContainerLoader) {
			return concreteContainerLoader.loadContainer(name).then(function(container){
				if(containerDecoratorProvider) {
					var decorators = containerDecoratorProvider.provide(name, container);
					return decorators.reduce(function(sequence, decorator){
						return sequence.then(function(){
							return decorator.apply(name, container);
						});
					}, ZHPromise.when());
				} else {
					return container;
				}
			});
		} else {
			return ZHPromise.reject({ err: ScreenService.i18n("A concrete container loader is necessary.") });
		}
	};

}